@@ -8,3 +8,11 @@ class FatalError(FlowmasterExeception):
 
 class AuthError(FatalError):
     ...
+
+
+class ForbiddenError(AuthError):
+    ...
+
+
+class PermissionError(AuthError):
+    ...
