@@ -1,111 +1,123 @@
-import atexit
 import datetime as dt
-from typing import Union, Iterable, Optional, Literal
+from functools import partial
+from typing import Union, Iterable, Optional, Sequence
 
 import orjson
 import peewee
 import pendulum
 import playhouse.sqlite_ext
 import pydantic
-from playhouse.sqliteq import SqliteQueueDatabase
+from playhouse.hybrid import hybrid_property
 
-from flowmaster.setttings import Settings
-from flowmaster.utils import iter_period_from_range, iter_range_datetime
-
-database = SqliteQueueDatabase(
-    # http://docs.peewee-orm.com/en/latest/peewee/playhouse.html#sqliteq
-    Settings.APP_HOME / "db.sqlite_ext",
-    pragmas=(
-        ("cache_size", -1024 * 64),  # 64MB page-cache.
-        ("journal_mode", "wal"),  # Use WAL-mode (you should always use this!).
-        ("foreign_keys", 1),
-    ),
-    use_gevent=False,  # Use the standard library "threading" module.
-    autostart=True,  # The worker thread now must be started manually.
-    queue_max_size=64,  # Max. # of pending writes that can accumulate.
-    results_timeout=3.0,  # Max. time to wait for query to be executed.
-)
-
-
-@atexit.register
-def _stop_worker_threads():
-    """http://docs.peewee-orm.com/en/latest/peewee/playhouse.html#sqliteq"""
-    database.stop()
-
-
-class BaseModel(playhouse.sqlite_ext.Model):
-    class Meta:
-        database = database
-
-
-class FlowStatus:
-    add = "ADD"
-    run = "RUN"
-    success = "SUCCESS"
-    error = "ERROR"
-    fatal_error = "FATAL_ERROR"
-    error_statuses = (error, fatal_error)
-    LiteralT = Literal[add, run, success, error, fatal_error]
-
-
-class FlowETLStep:
-    export = "EXPORT"
-    transform = "TRANSFORM"
-    load = "LOAD"
-    LiteralT = Literal[export, transform, load]
-
-
-class FlowOperator:
-    etl = "ETL"
-    LiteralT = Literal[etl]
+from flowmaster.database import db
+from flowmaster.enums import Statuses
+from flowmaster.utils import iter_period_from_range, iter_range_datetime, custom_encoder
+from flowmaster.utils.logging_helper import logger
 
 
 class DateTimeTZField(playhouse.sqlite_ext.DateTimeField):
     def python_value(self, value: str) -> dt.datetime:
-        dt_, tz_name = value.split(" ")
-        tz_info = pendulum.tz.timezone(tz_name)
-        return dt.datetime.fromisoformat(dt_).replace(tzinfo=tz_info)
+        dt_str, tz_name = value.split(" ")
+        return pendulum.parse(dt_str, tz=tz_name)
 
-    def db_value(self, value: dt.datetime) -> Optional[str]:
-        dt_ = pendulum.instance(value)
-        return f"{value.isoformat()} {dt_.timezone_name}" if value else None
+    def db_value(
+        self, value: Optional[Union[dt.datetime, pendulum.DateTime]]
+    ) -> Optional[str]:
+        if value is not None:
+            if not isinstance(value, pendulum.DateTime):
+                value = pendulum.instance(value)
+
+            dt_str = value.replace(tzinfo=None).isoformat()
+
+            return f"{dt_str} {value.timezone_name}"
 
 
-class FlowItem(BaseModel):
+class DateTimeUTCField(playhouse.sqlite_ext.DateTimeField):
+    def python_value(self, value: str) -> pendulum.DateTime:
+        if value is not None:
+            return pendulum.parse(value, tz=pendulum.timezone("UTC"))
+
+    def db_value(
+        self, value: Optional[Union[dt.datetime, pendulum.DateTime]]
+    ) -> Optional[str]:
+        if value is not None:
+            if value.tzinfo is None:
+                raise ValueError(f"{value} timezone not set.")
+
+            value = value.astimezone(pendulum.timezone("UTC"))
+            value = value.replace(tzinfo=None).isoformat()
+
+        return value
+
+
+class BaseDBModel(playhouse.sqlite_ext.Model):
+    class Meta:
+        database = db
+
+
+class FlowItem(BaseDBModel):
     """When changing fields, update to operators.etl.providers.flowmaster_data.policy.FlowmasterDataExportPolicy"""
 
     name = playhouse.sqlite_ext.CharField()
     worktime = DateTimeTZField()
 
-    operator = playhouse.sqlite_ext.CharField(null=True)
-    status = playhouse.sqlite_ext.CharField(default=FlowStatus.add, null=False)
-    etl_step = playhouse.sqlite_ext.CharField(null=True)
+    status = playhouse.sqlite_ext.CharField(default=Statuses.add, null=False)
     data = playhouse.sqlite_ext.JSONField(
-        default={}, json_dumps=orjson.dumps, json_loads=orjson.loads
+        default={},
+        json_dumps=partial(orjson.dumps, default=custom_encoder),
+        json_loads=orjson.loads,
     )
     notebook_hash = playhouse.sqlite_ext.CharField(default="", null=False)
     retries = playhouse.sqlite_ext.IntegerField(default=0)
     duration = playhouse.sqlite_ext.IntegerField(null=True)
-    log = playhouse.sqlite_ext.TextField(null=True)
-    expires_utc = playhouse.sqlite_ext.DateTimeField(null=True)
-    started_utc = playhouse.sqlite_ext.DateTimeField(null=True)
-    finished_utc = playhouse.sqlite_ext.DateTimeField(null=True)
-
-    created = playhouse.sqlite_ext.DateTimeField(default=dt.datetime.now())
-    updated = playhouse.sqlite_ext.DateTimeField(default=dt.datetime.now())
+    info = playhouse.sqlite_ext.TextField(null=True)
+    logpath = playhouse.sqlite_ext.TextField(null=True)
+    expires_utc = DateTimeUTCField(null=True)
+    started_utc = DateTimeUTCField(null=True)
+    finished_utc = DateTimeUTCField(null=True)
+    created_utc = DateTimeUTCField(default=pendulum.now("UTC"))
+    updated_utc = DateTimeUTCField(default=pendulum.now("UTC"))
 
     class Meta:
         primary_key = playhouse.sqlite_ext.CompositeKey("name", "worktime")
 
+    @hybrid_property
+    def worktime_for_url(self):
+        self.worktime: dt.datetime
+        tz_name = pendulum.instance(self.worktime).timezone_name.replace("/", ".")
+        worktime_str = self.worktime.strftime("%Y-%m-%dT%H:%M:%S")
+        return f"{worktime_str}Z{tz_name}"
+
+    @classmethod
+    def worktime_from_url(cls, worktime_for_url):
+        datetime, tz_name = worktime_for_url.split("Z")
+        tz_name = tz_name.replace(".", "/")
+        worktime = pendulum.parse(datetime, tz=tz_name)
+        return worktime
+
     @classmethod
     def count_items(
-        cls, flow_name: str, statuses: Optional[list[FlowStatus.LiteralT]] = None
+        cls, flow_name: str, statuses: Optional[list[Statuses.LiteralT]] = None
     ) -> int:
         query = cls.select().where(cls.name == flow_name)
         if statuses is not None:
             query = query.where(cls.status.in_(statuses))
         return query.count()
 
+    @classmethod
+    def count_items_by_name(cls) -> peewee.ModelSelect:
+        query = cls.select(
+            cls.name, peewee.fn.Count(cls.worktime).alias("count")
+        ).group_by(cls.name)
+        return query
+
+    @classmethod
+    def count_items_by_name_and_status(cls) -> peewee.ModelSelect:
+        query = cls.select(
+            cls.name, cls.status, peewee.fn.Count(cls.worktime).alias("count")
+        ).group_by(cls.name, cls.status)
+        return query
+
     @classmethod
     def exists(cls, flow_name: str) -> bool:
         return bool(cls.get_or_none(**{cls.name.name: flow_name}))
@@ -125,7 +137,7 @@ class FlowItem(BaseModel):
         if for_updated:
             items = items.order_by(cls.worktime.desc())
         else:
-            items = items.order_by(cls.updated.desc())
+            items = items.order_by(cls.updated_utc.desc())
 
         if items:
             return items.get()
@@ -134,9 +146,9 @@ class FlowItem(BaseModel):
     def change_status(
         cls,
         flow_name: str,
-        new_status: FlowStatus.LiteralT,
+        new_status: Statuses.LiteralT,
         *,
-        filter_statuses: Optional[tuple[FlowStatus.LiteralT]] = None,
+        filter_statuses: Optional[tuple[Statuses.LiteralT]] = None,
         from_time: Optional[dt.datetime] = None,
         to_time: Optional[dt.datetime] = None,
     ) -> int:
@@ -153,6 +165,53 @@ class FlowItem(BaseModel):
 
         return query.execute()
 
+    @classmethod
+    def change_expires(
+        cls,
+        flow_name: str,
+        expires: pendulum.DateTime,
+        *,
+        from_time: dt.datetime,
+        to_time: dt.datetime,
+    ) -> int:
+        query = cls.update(**{cls.expires_utc.name: expires}).where(
+            cls.name == flow_name, cls.worktime >= from_time, cls.worktime <= to_time
+        )
+
+        return query.execute()
+
+    @classmethod
+    def recreate_item(
+        cls,
+        flow_name: str,
+        worktime: dt.datetime,
+    ) -> list["FlowItem"]:
+        cls.clear(flow_name, worktime, worktime)
+        return cls.create_items(flow_name, [worktime])
+
+    @classmethod
+    def recreate_items(
+        cls,
+        flow_name: str,
+        filter_statuses: Optional[tuple[Statuses.LiteralT]] = None,
+        from_time: Optional[dt.datetime] = None,
+        to_time: Optional[dt.datetime] = None,
+    ) -> list["FlowItem"]:
+        query = cls.select().where(cls.name == flow_name)
+        if from_time:
+            query = query.where(cls.worktime >= from_time)
+
+        if to_time:
+            query = query.where(cls.worktime <= to_time)
+
+        if filter_statuses:
+            query = query.where(cls.status.in_(filter_statuses))
+
+        worktime_list = [i.worktime for i in query]
+        cls.clear(flow_name, from_time, to_time)
+
+        return cls.create_items(flow_name, worktime_list)
+
     @classmethod
     def is_create_next(
         cls,
@@ -167,8 +226,20 @@ class FlowItem(BaseModel):
         )
 
     @classmethod
-    def clear(cls, flow_name: str) -> int:
-        return cls.delete().where(cls.name == flow_name).execute()
+    def clear(
+        cls,
+        flow_name: str,
+        from_time: Optional[dt.datetime] = None,
+        to_time: Optional[dt.datetime] = None,
+    ) -> int:
+        query = cls.delete().where(cls.name == flow_name)
+        if from_time:
+            query = query.where(cls.worktime >= from_time)
+
+        if to_time:
+            query = query.where(cls.worktime <= to_time)
+
+        return query.execute()
 
     @classmethod
     def create_next_execute_item(
@@ -179,16 +250,19 @@ class FlowItem(BaseModel):
     ) -> Optional["FlowItem"]:
         if cls.is_create_next(flow_name, interval_timedelta, worktime):
             last_executed_item = cls.last_item(flow_name, for_updated=True)
-            next_execute_datetime = last_executed_item.worktime + interval_timedelta
+            next_worktime = last_executed_item.worktime + interval_timedelta
             try:
-                return cls.create(
+                item = cls.create(
                     **{
                         cls.name.name: flow_name,
-                        cls.worktime.name: next_execute_datetime,
+                        cls.worktime.name: next_worktime,
                     }
                 )
             except peewee.IntegrityError:
                 return None
+            else:
+                logger.info("Created next worktime {} for {}", next_worktime, flow_name)
+                return item
 
     @classmethod
     def create_missing_items(
@@ -206,6 +280,8 @@ class FlowItem(BaseModel):
                 )
             except peewee.IntegrityError:
                 item = cls.get(cls.name == flow_name, cls.worktime == datetime_)
+            else:
+                logger.info("Created missing worktime {} for {}", datetime_, flow_name)
 
             items.append(item)
 
@@ -230,15 +306,21 @@ class FlowItem(BaseModel):
 
         first_item = cls.first_item(flow_name)
         if first_item:
-            dates = [
+            worktime_list = [
                 worktime + (interval_timedelta * delta) for delta in offset_periods
             ]
-            dates = list(filter(lambda dt_: dt_ >= first_item.worktime, dates))
+            worktime_list = list(
+                filter(lambda dt_: dt_ >= first_item.worktime, worktime_list)
+            )
 
-            cls.delete().where(cls.name == flow_name, cls.worktime.in_(dates)).execute()
+            cls.delete().where(
+                cls.name == flow_name, cls.worktime.in_(worktime_list)
+            ).execute()
 
             items = []
-            for date1, date2 in iter_period_from_range(dates, interval_timedelta):
+            for date1, date2 in iter_period_from_range(
+                worktime_list, interval_timedelta
+            ):
                 new_items = cls.create_missing_items(
                     flow_name,
                     start_time=date1,
@@ -247,6 +329,12 @@ class FlowItem(BaseModel):
                 )
                 items.extend(new_items)
 
+            logger.info(
+                "Recreated items to restart flows {} for previous worktimes {}",
+                flow_name,
+                worktime_list,
+            )
+
             return items
 
     @classmethod
@@ -259,38 +347,55 @@ class FlowItem(BaseModel):
             # Check limit fatal errors.
             items = (
                 cls.select()
-                .where(cls.name == flow_name, cls.status == FlowStatus.fatal_error)
-                .order_by(cls.updated.desc())
+                .where(cls.name == flow_name, cls.status == Statuses.fatal_error)
+                .order_by(cls.updated_utc.desc())
                 .limit(max_fatal_errors)
             )
-            return len(items) < max_fatal_errors
+            is_allow = len(items) < max_fatal_errors
+            if not is_allow:
+                logger.info("Many fatal errors, {} will not be scheduled", flow_name)
+
+            return is_allow
         else:
             return True
 
     @classmethod
     def retry_error_items(
         cls, flow_name: str, retries: int, retry_delay: int
-    ) -> list["FlowItem"]:
+    ) -> peewee.ModelSelect:
         # http://docs.peewee-orm.com/en/latest/peewee/hacks.html?highlight=time%20now#date-math
         # A function that checks to see if retry_delay passes to restart.
-        ex = peewee.fn.datetime(
-            peewee.fn.strftime("%s", cls.started_utc) + retry_delay, "unixepoch"
-        )
+        next_start_time_timestamp = cls.finished_utc.to_timestamp() + retry_delay
         items = cls.select().where(
             cls.name == flow_name,
-            cls.status.in_(FlowStatus.error_statuses),
+            cls.status.in_(Statuses.error_statuses),
             cls.retries < retries,
-            cls.get_utcnow() >= ex,
+            (
+                (pendulum.now("UTC").timestamp() >= next_start_time_timestamp)
+                | (cls.finished_utc.is_null())
+            ),
+            # TODO: В поле info записывать, что поток не будет перезапущен, т.к. истек срок выполнения.
+            #  Иначе не понятно, почему не перезапускаются.
+            (
+                (pendulum.now("UTC").timestamp() <= cls.expires_utc.to_timestamp())
+                | (cls.expires_utc.is_null())
+            ),
         )
         worktimes = [i.worktime for i in items]
 
-        cls.update(
-            **{
-                cls.status.name: FlowStatus.add,
-                cls.retries.name: cls.retries + 1,
-                cls.updated.name: dt.datetime.now(),
-            }
-        ).where(cls.name == flow_name, cls.worktime.in_(worktimes)).execute()
+        if worktimes:
+            # TODO: recreate items
+            cls.update(
+                **{
+                    cls.status.name: Statuses.add,
+                    cls.retries.name: cls.retries + 1,
+                    cls.updated_utc.name: pendulum.now("UTC"),
+                }
+            ).where(cls.name == flow_name, cls.worktime.in_(worktimes)).execute()
+
+            logger.info(
+                "Restart error items for {}, worktimes = {}", flow_name, worktimes
+            )
 
         return (
             cls.select()
@@ -319,6 +424,9 @@ class FlowItem(BaseModel):
         ):
             if not cls.exists(flow_name):
                 cls.create(**{cls.name.name: flow_name, cls.worktime.name: worktime})
+                logger.info(
+                    "Created first item for {}, worktime {}", flow_name, worktime
+                )
 
             if cls.create_next_execute_item(flow_name, interval_timedelta, worktime):
                 if update_stale_data:
@@ -338,8 +446,14 @@ class FlowItem(BaseModel):
                 cls.select()
                 .where(
                     cls.name == flow_name,
-                    cls.status == FlowStatus.add,
-                    (dt.datetime.utcnow() <= cls.expires_utc | cls.expires_utc == None),
+                    cls.status == Statuses.add,
+                    (
+                        (
+                            pendulum.now("UTC").timestamp()
+                            <= cls.expires_utc.to_timestamp()
+                        )
+                        | (cls.expires_utc.is_null())
+                    ),
                 )
                 .order_by(cls.worktime.desc())
             )
@@ -347,26 +461,32 @@ class FlowItem(BaseModel):
     @classmethod
     def clear_statuses_of_lost_items(cls) -> None:
         cls.update(
-            **{cls.status.name: FlowStatus.error, cls.log.name: "ExpiredError"}
-        ).where(dt.datetime.utcnow() <= cls.expires_utc).execute()
+            **{cls.status.name: Statuses.error, cls.info.name: "ExpiredError"}
+        ).where(
+            pendulum.now("UTC").timestamp() >= cls.expires_utc.to_timestamp()
+        ).execute()
 
-        cls.update(**{cls.status.name: FlowStatus.add}).where(
-            cls.status.in_([FlowStatus.run])
+        cls.update(**{cls.status.name: Statuses.add}).where(
+            cls.status.in_([Statuses.run])
         ).execute()
 
     @classmethod
     def create_items(
-        cls, flow_name: str, worktime_list: Iterable[dt.datetime], **data
+        cls, flow_name: str, worktime_list: Iterable[dt.datetime], **kwargs
     ) -> list["FlowItem"]:
         items = []
         for datetime_ in worktime_list:
             try:
                 item = cls.create(
-                    **data,
-                    **{cls.name.name: flow_name, cls.worktime.name: datetime_},
+                    **{
+                        cls.name.name: flow_name,
+                        cls.worktime.name: datetime_,
+                        **kwargs,
+                    },
                 )
             except peewee.IntegrityError:
                 item = cls.get(cls.name == flow_name, cls.worktime == datetime_)
+                cls.update_items([item], **kwargs)
 
             items.append(item)
 
@@ -378,13 +498,13 @@ class FlowItem(BaseModel):
         items: list["FlowItem"],
         save: bool = True,
         save_expression_fields: bool = True,
-        **data,
+        **kwargs,
     ) -> dict:
-        data.update({cls.updated.name: dt.datetime.now()})
+        kwargs.update({cls.updated_utc.name: pendulum.now("UTC")})
         not_saved_data = {}
 
         for item in items:
-            for field, value in data.items():
+            for field, value in kwargs.items():
                 if field in cls.__dict__:
                     if (
                         isinstance(value, peewee.Expression)
@@ -402,15 +522,24 @@ class FlowItem(BaseModel):
         return not_saved_data
 
     @classmethod
-    def iter_items(cls, flow_name: str, limit: int = 20) -> list["FlowItem"]:
-        return (
+    def iter_items(
+        cls,
+        flow_name: str,
+        statuses: Optional[Sequence[Statuses.LiteralT]] = None,
+        limit: int = 20,
+        offset: int = 0,
+    ) -> peewee.ModelSelect:
+        query = (
             FlowItem.select()
             .where(FlowItem.name == flow_name)
             .order_by(cls.worktime.desc())
             .limit(limit)
+            .offset(offset)
         )
+        if statuses is not None:
+            query = query.where(cls.status.in_(statuses))
 
-    @staticmethod
-    def get_utcnow() -> dt.datetime:
-        """For mock"""
-        return dt.datetime.utcnow()
+        return query
+
+
+db.create_tables([FlowItem])
