@@ -1,19 +1,22 @@
 import datetime as dt
+from contextlib import contextmanager
 from typing import Iterator, Optional, TYPE_CHECKING
 
 import pendulum
 
+from flowmaster.enums import Statuses
 from flowmaster.models import FlowItem
 from flowmaster.utils import iter_range_datetime, iter_period_from_range
 from flowmaster.utils.logging_helper import Logger, getLogger
 
 if TYPE_CHECKING:
-    from flowmaster.operators.base.policy import Notebook
+    from flowmaster.operators.base.policy import BaseNotebook
+    from flowmaster.operators.etl.core import BaseOperator
     from flowmaster.executors import ExecutorIterationTask
 
 
 class Work:
-    def __init__(self, notebook: "Notebook", logger: Optional[Logger] = None):
+    def __init__(self, notebook: "BaseNotebook", logger: Optional[Logger] = None):
         self.notebook = notebook
         self.name = notebook.name
         self.interval_timedelta = notebook.work.triggers.schedule._interval_timedelta
@@ -24,7 +27,9 @@ class Work:
         self.keep_sequence = notebook.work.triggers.schedule.keep_sequence
         self.retry_delay = notebook.work.retry_delay
         self.retries = notebook.work.retries
+        self.max_fatal_errors = notebook.work.max_fatal_errors
         self.soft_time_limit_seconds = notebook.work.soft_time_limit_seconds
+        # TODO: move to policy
         if notebook.work.time_limit_seconds_from_worktime is not None:
             self.expires = self.current_worktime + dt.timedelta(
                 seconds=notebook.work.time_limit_seconds_from_worktime
@@ -39,18 +44,6 @@ class Work:
         self.Model = FlowItem
         self.logger = logger or getLogger()
 
-        self.concurrency_pool_names = notebook.work.pools or []
-        if self.notebook.work.concurrency is not None:
-            self.concurrency_pool_names.append(f"__{self.name}_concurrency__")
-            self.add_pool(
-                f"__{self.name}_concurrency__", self.notebook.work.concurrency
-            )
-
-    def add_pool(self, name: str, limit: int) -> None:
-        from flowmaster.pool import pools
-
-        pools.update_pools({name: limit})
-
     @property
     def current_worktime(self) -> dt.datetime:
         """
@@ -60,6 +53,8 @@ class Work:
 
         if self.start_datetime > end_time:
             start_time = self.start_datetime - self.interval_timedelta
+            if start_time > end_time:
+                raise ValueError(f"{start_time=} > {end_time=}")
         else:
             start_time = self.start_datetime
 
@@ -88,8 +83,8 @@ class Work:
             self.keep_sequence,
             self.retries,
             self.retry_delay,
-            notebook_hash="",
-            max_fatal_errors=3,
+            notebook_hash=self.notebook.hash,
+            max_fatal_errors=self.max_fatal_errors,
         )
 
     def iter_datetime_for_execute(self) -> Iterator[dt.datetime]:
@@ -109,6 +104,28 @@ class Work:
         )
 
 
+@contextmanager
+def prepare_items_for_order(
+    flow: "BaseOperator", start_period: dt.datetime, end_period: dt.datetime
+):
+    # The status is changed so that there is no repeated ordering of tasks.
+    FlowItem.change_status(
+        flow.name,
+        new_status=Statuses.run,
+        from_time=start_period,
+        to_time=end_period,
+    )
+    if flow.Work.expires is not None:
+        FlowItem.change_expires(
+            flow.name,
+            expires=flow.Work.expires,
+            from_time=start_period,
+            to_time=end_period,
+        )
+
+    yield
+
+
 def ordering_flow_tasks(*, dry_run: bool = False) -> Iterator["ExecutorIterationTask"]:
     from flowmaster.operators.etl.work import ordering_etl_flow_tasks
 
