@@ -1,3 +1,3 @@
 from flowmaster.operators.etl.dataschema import ExportContext
+from flowmaster.operators.etl.enums import DataOrient
 from flowmaster.operators.etl.providers.abstract import ProviderAbstract, ExportAbstract
-from flowmaster.operators.etl.types import DataOrient
