@@ -3,14 +3,19 @@ from typing import Optional, Union
 
 import pydantic
 
-from flowmaster.operators.etl.types import DataOrient
+from flowmaster.operators.etl.enums import DataOrient, ETLSteps
 
 
-class ETLContext(pydantic.BaseModel):
+class OperatorContext(pydantic.BaseModel):
+    operator: str
+
+
+class ETLContext(OperatorContext):
     storage: str
     db: str = None
     table: str = None
     path: str = None
+    step: Optional[ETLSteps.LiteralT] = None
     start_period: dt.datetime = None
     end_period: dt.datetime = None
     size: Optional[pydantic.PositiveInt] = 0
@@ -23,7 +28,8 @@ class ExportContext(pydantic.BaseModel):
     columns: Union[list, tuple, set]
     data: list
     data_orient: DataOrient.LiteralT
-    export_kwargs: dict = pydantic.Field(default_factory=dict)
+    request_kwargs: dict = pydantic.Field(default_factory=dict)
+    response_kwargs: dict = pydantic.Field(default_factory=dict)
 
 
 class TransformContext(pydantic.BaseModel):
