@@ -1,16 +1,17 @@
-import datetime as dt
 import pathlib
 from functools import partial
 from typing import TYPE_CHECKING, Optional
 
 import jinja2
 import orjson
+import pendulum
 
+from flowmaster.operators.etl.enums import DataOrient
 from flowmaster.operators.etl.loaders.csv.policy import (
     CSVLoadPolicy,
     CSVTransformPolicy,
 )
-from flowmaster.operators.etl.types import DataOrient
+from flowmaster.utils import custom_encoder
 from flowmaster.utils.logging_helper import Logger, getLogger
 
 if TYPE_CHECKING:
@@ -40,7 +41,7 @@ class CSVLoader:
             name=notebook.name,
             provider=notebook.provider,
             storage=notebook.storage,
-            datetime=dt.datetime.now(),
+            datetime=pendulum.now("local"),
         )
         self.file_name = jinja2.Template(notebook.load.file_name).render(**_template)
         self.add_data_before = jinja2.Template(notebook.load.add_data_before).render(
@@ -57,11 +58,11 @@ class CSVLoader:
         self.file_path = pathlib.Path(self.path) / self.file_name
         self.open_file = partial(open, self.file_path, encoding=self.encoding)
 
-    def set_context(self, model: "ETLContext") -> None:
+    def update_context(self, model: "ETLContext") -> None:
         model.path = str(self.file_path)
 
     def values_to_text(self, data: list) -> str:
-        func_dump_value = lambda value: orjson.dumps(value).decode()
+        func_dump_value = lambda value: orjson.dumps(value, custom_encoder).decode()
         func_row_to_line = lambda row: self.sep.join(map(func_dump_value, row))
         data = self.newline.join(map(func_row_to_line, data))
         data += self.newline
@@ -85,8 +86,7 @@ class CSVLoader:
 
         with self.open_file(mode="a") as f:
             f.write(self.add_data_after)
-
-        self.logger.info(f"Save data to file: {f.name}")
+        self.logger.info("Save data to file: {}", f.name)
 
     def __call__(self, context: "TransformContext", *args, **kwargs) -> None:
         if self._enter is False:
@@ -114,4 +114,4 @@ class CSVLoader:
 
         self.insert_counter += 1
 
-        self.logger.info(f"Add data to file: {f.name}")
+        self.logger.info("Add data to file: {}", f.name)
