@@ -2,8 +2,8 @@ import csv
 from typing import TYPE_CHECKING, Iterator
 
 from flowmaster.operators.etl.dataschema import ExportContext
+from flowmaster.operators.etl.enums import DataOrient
 from flowmaster.operators.etl.providers.abstract import ExportAbstract
-from flowmaster.operators.etl.types import DataOrient
 from flowmaster.utils import chunker
 
 if TYPE_CHECKING:
@@ -52,7 +52,6 @@ class CSVExport(ExportAbstract):
                 size=self.export.chunk_size,
             ):
                 yield ExportContext(
-                    export_kwargs={},
                     columns=self.export.columns,
                     data=chunk,
                     data_orient=data_orient,
