@@ -12,18 +12,16 @@ class FlowmasterDataExportPolicy(BasePolicy):
             Literal[
                 "name",
                 "worktime",
-                "operator",
                 "status",
-                "etl_step",
                 "data",
                 "notebook_hash",
                 "retries",
                 "duration",
-                "log",
+                "info",
                 "started_utc",
                 "finished_utc",
-                "created",
-                "updated",
+                "created_utc",
+                "updated_utc",
             ],
             # pools
             Literal["name", "size", "limit", "datetime"],
