@@ -3,8 +3,8 @@ from typing import TYPE_CHECKING, Iterator
 import peewee
 
 from flowmaster.operators.etl.dataschema import ExportContext
+from flowmaster.operators.etl.enums import DataOrient
 from flowmaster.operators.etl.providers.abstract import ExportAbstract
-from flowmaster.operators.etl.types import DataOrient
 from flowmaster.utils import chunker
 
 if TYPE_CHECKING:
@@ -45,7 +45,6 @@ class SQLiteExport(ExportAbstract):
             size=self.export.chunk_size,
         ):
             yield ExportContext(
-                export_kwargs={},
                 columns=self.export.columns,
                 data=chunk,
                 data_orient=DataOrient.values,
