@@ -1,13 +1,10 @@
 import datetime as dt
 from typing import TYPE_CHECKING, Optional, Iterator
 
-from tapi_yandex_metrika import YandexMetrikaStats
-from tapi_yandex_metrika.exceptions import YandexMetrikaTokenError
-
 from flowmaster.exceptions import AuthError
 from flowmaster.operators.etl.dataschema import ExportContext
+from flowmaster.operators.etl.enums import DataOrient
 from flowmaster.operators.etl.providers.abstract import ExportAbstract
-from flowmaster.operators.etl.types import DataOrient
 from flowmaster.utils.logging_helper import Logger
 
 if TYPE_CHECKING:
@@ -16,8 +13,11 @@ if TYPE_CHECKING:
 
 class YandexMetrikaStatsExport(ExportAbstract):
     def __init__(self, notebook: "ETLNotebook", logger: Optional[Logger] = None):
+        from tapi_yandex_metrika import YandexMetrikaStats
+
         self.credentials = notebook.export.credentials.dict()
         self.params = notebook.export.params.dict()
+        self.client = YandexMetrikaStats(**self.credentials)
         super(YandexMetrikaStatsExport, self).__init__(notebook, logger)
 
     @classmethod
@@ -25,10 +25,6 @@ class YandexMetrikaStatsExport(ExportAbstract):
         assert "ids" in params
         assert "metrics" in params
 
-    @property
-    def client(self) -> YandexMetrikaStats:
-        return YandexMetrikaStats(**self.credentials)
-
     def collect_params(
         self, start_period: dt.datetime, end_period: dt.datetime, **kwargs
     ) -> dict:
@@ -46,6 +42,8 @@ class YandexMetrikaStatsExport(ExportAbstract):
     def __call__(
         self, start_period: dt.datetime, end_period: dt.datetime, **kwargs
     ) -> Iterator[ExportContext]:
+        from tapi_yandex_metrika.exceptions import YandexMetrikaTokenError
+
         try:
             params = self.collect_params(start_period, end_period)
 
@@ -55,7 +53,7 @@ class YandexMetrikaStatsExport(ExportAbstract):
                 self.logger.info("Iter export data")
 
                 yield ExportContext(
-                    export_kwargs=result().request_kwargs,
+                    request_kwargs=result().request_kwargs,
                     columns=report.columns,
                     data=result().to_columns(),
                     data_orient=DataOrient.columns,
