@@ -1,7 +1,8 @@
-import datetime as dt
 from collections import defaultdict
 from typing import Literal
 
+import pendulum
+
 from flowmaster.setttings import Settings
 from flowmaster.utils.logging_helper import logger
 from flowmaster.utils.yaml_helper import YamlHelper
@@ -50,7 +51,7 @@ class Pool:
             is_free = self.sizes[tag][tag] < self.limits[tag]
             results.append(is_free)
             if is_free is False:
-                logger.debug(f"Pool '{tag}' full")
+                logger.debug("Pool '{}' full", tag)
 
         return all(results)
 
@@ -69,24 +70,35 @@ class Pool:
         counter: Counter = self.sizes[tag]
         return counter[tag]
 
-    def info(self) -> list[dict]:
+    def info(self, only_used=True) -> list[dict]:
         data = []
         for tag, limit in self.limits.items():
+            if only_used and self[tag] == 0:
+                continue
+
             data.append(
                 {
                     "name": tag,
                     "size": self[tag],
                     "limit": limit,
-                    "datetime": dt.datetime.now(),
+                    "datetime": pendulum.now("local"),
                 }
             )
 
         return data
 
+    def info_text(self, only_used=True) -> str:
+        info_list = self.info(only_used)
+        text = ""
+        for tag in info_list:
+            text += f"\n\t{tag['name']} {tag['size']}/{tag['limit']}\n"
+
+        return text or "all pools are free"
+
     def __str__(self) -> str:
         text = ""
         for tag, limit in self.limits.items():
-            text += f"{tag}: {self[tag]}, limit={limit}\n"
+            text += f"{tag}: {self[tag]}/{limit}\n"
 
         return str(text)
 
