@@ -9,8 +9,10 @@ class Settings:
     else:
         APP_HOME = Path.home() / "FlowMaster"
 
+    WEBUI_PORT = os.environ.get("FLOWMASTER_PORT", 8822)
     FILE_STORAGE_DIR = APP_HOME / "storage"
     NOTEBOOKS_DIR = APP_HOME / "notebooks"
+    ARCHIVE_NOTEBOOKS_DIR = NOTEBOOKS_DIR / "__archive__"
     LOGS_DIR = APP_HOME / "logs"
     PLUGINS_DIRNAME = "plugins"
     PLUGINS_DIR = APP_HOME / PLUGINS_DIRNAME
