@@ -8,7 +8,7 @@ from loguru._logger import Logger
 from flowmaster.setttings import Settings
 
 
-def get_logfile_path(filename: str, relative_path: str = None) -> Path:
+def create_logfile(filename: str, relative_path: str = None) -> Path:
     Path.mkdir(Settings.LOGS_DIR, exist_ok=True)
     path = Settings.LOGS_DIR
 
@@ -26,11 +26,12 @@ def getLogger() -> Logger:
     logger = Logger(_Core(), None, 0, False, False, False, False, True, None, {})
     logger.add(_sys.stderr)
     _atexit.register(logger.remove)
+
     return logger
 
 
 logger.add(
-    get_logfile_path("{time:%Y-%m-%d}.log", "app"),
+    create_logfile("{time:%Y-%m-%d}.log", "app"),
     level="INFO",
     rotation="100 MB",
     retention="30 days",
@@ -38,4 +39,15 @@ logger.add(
     colorize=True,
     backtrace=True,
     diagnose=True,
+    encoding="utf8",
+)
+logger.add(
+    create_logfile("errors.log", "app"),
+    level="ERROR",
+    rotation="20 MB",
+    enqueue=True,
+    colorize=True,
+    backtrace=True,
+    diagnose=True,
+    encoding="utf8",
 )
