@@ -1,9 +1,5 @@
 from pathlib import Path
 
-from flowmaster.models import FlowItem, database
-
-database.create_tables([FlowItem])
-
 
 def get_tests_dir(test_dir_name: str = "tests") -> Path:
     cwd = Path.cwd()
