@@ -1,11 +1,11 @@
 import datetime as dt
 
-from flowmaster.operators.etl.service import ETLOperator
+from flowmaster.operators.etl.core import ETLOperator
 
 
 def test_flow_csv_to_csv_with_columns(csv_to_csv_with_columns_notebook):
     etl_flow = ETLOperator(csv_to_csv_with_columns_notebook)
-    list(etl_flow(dt.datetime(2021, 2, 1), dt.datetime(2021, 2, 1)))
+    etl_flow.dry_run(dt.datetime(2021, 2, 1), dt.datetime(2021, 2, 1))
 
     with etl_flow.Load.open_file(mode="r") as loadfile:
         data = loadfile.readlines()
@@ -22,7 +22,7 @@ def test_flow_csv_to_csv_with_columns(csv_to_csv_with_columns_notebook):
 
 def test_flow_csv_to_csv_without_columns(csv_to_csv_without_columns_notebook):
     etl_flow = ETLOperator(csv_to_csv_without_columns_notebook)
-    list(etl_flow(dt.datetime(2021, 2, 1), dt.datetime(2021, 2, 1)))
+    etl_flow.dry_run(dt.datetime(2021, 2, 1), dt.datetime(2021, 2, 1))
 
     with etl_flow.Load.open_file(mode="r") as loadfile:
         data = loadfile.readlines()
