@@ -1,14 +1,12 @@
 import datetime as dt
 
-from flowmaster.models import FlowItem
-from flowmaster.operators.etl.service import ETLOperator
+from flowmaster.operators.etl.core import ETLOperator
 
 
 def test_flow_flowmaster_items(flowmasterdata_items_to_csv_notebook):
-    FlowItem.clear(flowmasterdata_items_to_csv_notebook.name)
-
     etl_flow = ETLOperator(flowmasterdata_items_to_csv_notebook)
-    list(etl_flow(dt.datetime(2021, 2, 1), dt.datetime(2021, 2, 5)))
+    task = etl_flow.task(dt.datetime(2021, 2, 5), dt.datetime(2021, 2, 5))
+    list(task)
 
     with etl_flow.Load.open_file(mode="r") as loadfile:
         data = loadfile.readlines()
@@ -17,7 +15,7 @@ def test_flow_flowmaster_items(flowmasterdata_items_to_csv_notebook):
         [row for row in data if flowmasterdata_items_to_csv_notebook.name in row]
     )
 
-    assert count_items == 5
+    assert count_items == 1
 
 
 def test_flow_flowmasterdata_pools(
@@ -26,7 +24,7 @@ def test_flow_flowmasterdata_pools(
     flowmasterdata_items_to_csv_notebook.export = flowmasterdata_pools_export_policy
 
     etl_flow = ETLOperator(flowmasterdata_items_to_csv_notebook)
-    list(etl_flow(dt.datetime(2021, 2, 1), dt.datetime(2021, 2, 1)))
+    etl_flow.dry_run(dt.datetime(2021, 2, 1), dt.datetime(2021, 2, 1))
 
     with etl_flow.Load.open_file(mode="r") as loadfile:
         data = loadfile.readlines()
@@ -34,14 +32,16 @@ def test_flow_flowmasterdata_pools(
     assert [
         row
         for row in data
-        if "__flowmasterdata_items_to_csv_export_concurrency__" in row
+        if "____test_flowmasterdata_items_to_csv___export_concurrency__" in row
     ]
     assert [
         row
         for row in data
-        if "__flowmasterdata_items_to_csv_transform_concurrency__" in row
+        if "____test_flowmasterdata_items_to_csv___transform_concurrency__" in row
     ]
     assert [
-        row for row in data if "__flowmasterdata_items_to_csv_load_concurrency__" in row
+        row
+        for row in data
+        if "____test_flowmasterdata_items_to_csv___load_concurrency__" in row
     ]
     assert [row for row in data if "name\tsize\tlimit\tdatetime" in row]
